.. _reference:

API Reference
=============
Welcome to the API documentation for the stravalib package.
Below the main modules are listed.

.. warning::
   Note that only public facing methods are documented here.

.. toctree::
  :maxdepth: 2

  Client <reference/client>
  Model <reference/model>
  Attributes <reference/attributes>
  Exceptions <reference/exceptions>
  Unit helper <reference/unithelper>
  Protocol <reference/protocol>
  Utility Submodule <reference/utilities>